#include "request.hh"
#include "input-score.hh"
#include "input-staff.hh"
#include "input-music.hh"
#include "input-register.hh"
#include "molecule.hh"
#include "voice-element.hh"
#include "plist.tcc"
#include "pcursor.tcc"

IPL_instantiate(Atom);
IPL_instantiate(Input_staff);
IPL_instantiate(Input_music);
IPL_instantiate(Input_register);
